# PyNGL

This is the code for the full python version of [NGL](https://github.com/NCCA/NGL) the ncca graphics library.

More details soon as this is work in progress.


## Test

use

```
uv run pytest
```

To run tests,

```
uv run pytest --cov=src --cov-report=term-missing
```

For coverage reports.
